<?php
function generateMailHeader($header)
{
    $string = "";
    foreach ($header as $headerName => $headerContent)
    {
    	$string.= $headerName.': '.trim($headerContent)."\n";
    }
    
    return $string;
}

function getGroupData( $obj )
{
    $arrTemp = array();
    
    if( is_object($obj) && isset($obj->Fields) )
    {
        foreach( $obj->Fields as $oneReturn )
        {
            $arrTemp[ $oneReturn->Key ] = $oneReturn->Value;
        }
    }
    
    return $arrTemp;
}

function generateOption( $name , $array , $formatFunction='', $translateArray=array() , $filterRequest=array() )
{
    $return = '';
    if( is_array($array) && count($array)>0 )
    {
        $return.= '<option value="">---</option>'."\n";
        foreach ( $array as $key => $value )
        {
            if( $value!='' )
            {
                if( array_key_exists($key,$translateArray) )
                {
                    $value = $translateArray[$key];
                }
                
                if( function_exists($formatFunction) )
                {
                    $value = call_user_func($formatFunction,$value);
                }
                
                $return.='<option value="'.$key.'" '.isOptionSelected($filterRequest,$name,$key).'>'.$value.'</option>'."\n";
            }
        }
    }
    return $return;
}

function isCheckboxChecked( $arr , $name , $value=1 )
{
    if( is_array($arr) )
    {
        if( array_key_exists($name,$arr) )
        {
            if( $arr[$name]==$value )
            {
                return ' checked="checked" ';
            }
        }
    }
}

function isOptionSelected( $arr , $name , $value )
{
    if( is_array($arr) )
    {
        if( array_key_exists($name,$arr) )
        {
            if( $arr[$name]==$value && $arr[$name]!='' )
            {
                return ' selected="selected" ';
            }
        }
    }
}

function formatDate($datestring)
{
    if($datestring=='0000-00-00' )
    {
        return '00.00.0000';
    }
    else
    {
		$arrdate = explode('-',$datestring);
		
		$string = '';
		if( $arrdate[1]!='00' )
		{
			if( $arrdate[2]!='00' )
			{
				$string.= $arrdate[2].'.';
			}
			
			$string.= $arrdate[1].'.';
		}
		
		$string.= $arrdate[0];
		return $string;
    }
}

function formatKW($kw)
{
    return sprintf('%u kw',$kw);
}

function formatKM($km)
{
    return sprintf('%u km',$km);
}

function formatEZ( $ez )
{
    $return = '';
    if( $ez!='' && $ez!='0000-00-00' )
    {
        $parts = explode('-',$ez);
        
        if( intval($parts[1])>0 )
        {
            $return.= $parts[1].'/';
        }
        
        $return.= $parts[0];
    }
    else
    {
        $return.= '-';
    }
    return $return;
}

function formatAccs( $accs , $CCAPI_LANG )
{
        //$accs = $oneCar->AccsList->Accs;
        $namen = array();
        foreach ( $accs as $obj )
        {
            $tmpname = $CCAPI_LANG['accs'][ $obj->Key.'.'.$obj->Value ];
            $namen[$tmpname] = $tmpname;
        }
        ksort($namen);
        
        return ( implode(', ',$namen) );
//        echo '<div class="accs"><h3>Ausstattung</h3>';
//        echo '<div>',htmlentities( implode(', ',$namen) ),'</div>';
//        echo '</div>';
}





/**
 * do a cached search for vehicles
 *
 * @param array $query
 * @param SoapClient $client
 */
function cachedSearchCar( $query , $client )
{
    $key = getCacheResultKey( $query , $client , 'search' , 'doVehicleFilterView' );
    $return = getCachedResult( $key , 'search' );
    return $return;
}

/**
 * do a cached search for vehicles
 *
 * @param array $query
 * @param SoapClient $client
 */
function cachedViewCar( $query , $client )
{
    $key = getCacheResultKey( $query , $client , 'vehicle' , 'doVehicleFilterView' );
    $return = getCachedResult( $key , 'vehicle' );
    return $return;
}

/**
 * do a cached search for vehicles
 *
 * @param array $query
 * @param SoapClient $client
 */
function cachedSearchList( $query , $client )
{
    $key = getCacheResultKey( $query , $client , 'lists' , 'doVehicleFieldGroupView' );
    $return = getCachedResult( $key , 'lists' );
    return $return;
}

/**
 * do a cached search for vehicles
 *
 * @param string $label
 * @param string $lang
 * @param SoapClient $client
 */
function chachedLabels($label , $lang , $client)
{
    $key = getCacheResultKey( array($label , $lang) , $client , 'labels' , 'getValueTranslations' );
    $return = getCachedResult( $key , 'labels' );
    return $return;
}

/**
 * do a cached webservice call
 *
 * @param array $query
 * @param SoapClient $client
 * @param string $folder
 * @param string $function
 * @return string
 */
function getCacheResultKey( $query , $client , $folder , $function )
{
    $querySerial = serialize( $query );
    $key = sha1($querySerial);
    
    $cacheFileName = CCAPI_CACHEDIR.$folder.DIRECTORY_SEPARATOR.$key;
    
    $maxAge = time()-CCAPI_CACHETIME;
    
    if( !file_exists( $cacheFileName ) || filemtime($cacheFileName)<$maxAge )
    {
        try {
			error_log(var_export($query,true));
            $return = call_user_func_array( array($client,$function) , $query );
            $sResult = serialize( $return );
            file_put_contents( $cacheFileName , $sResult );
        }
        catch( Exception $e )
        {
            echo $e->getMessage();
            if( !file_exists( $cacheFileName ) ) // use old cache if its there
            {
                $key=false;
            }
        }
    }
    
    return $key;
}

/**
 * get cached results
 *
 * @param string $key
 * @param string $folder
 * @return mixed
 */
function getCachedResult( $key , $folder )
{
    $cacheFileName = CCAPI_CACHEDIR.$folder.DIRECTORY_SEPARATOR.$key;
    if( file_exists($cacheFileName) )
    {
        $file = file_get_contents($cacheFileName);
        return unserialize( $file );
    }
    else
    {
        return false;
    }
}

?>